#version 3.1;

/*
 * A distant keep across a mountain valley. From Chapter 2,
 * RTOH campaign. This is believed to be the keep of
 * Desatysso.
 *
 * Scale is 1 POVunit == 1 foot.
 *
 * Created 3/24/99 by Denton Gentry.
 */

#include "colors.inc"
#include "stones.inc"

camera {
	location <-20,20,80>
	look_at <-10,0,0>
}

light_source { <0, 200, 60> color Gray30 }
light_source { <-50, 200, 60> color Gray30 }
light_source { <50, 200, 60> color Gray30 }
light_source { <0, 200, 0> color Gray30 }

global_settings {
	assumed_gamma 1.8
	ambient_light rgb<1, 1, 1>
}

background { White }

// Texture by Chuck Fusner, http://www.enter.net/~cfusner
#local RoughStone = texture { //rough stone texture...
	pigment { //nice and random on the pigment.
		granite
		color_map {
		[ 0 rgb .5 ]
		[ .25 rgb .65 ]
		[ .5 rgb .5 ]
		[ .75 rgb .7 ]
		[ 1 rgb .5 ]
		}
		frequency 100
	}
	normal {
		crackle 1
//		warp {
//		turbulence <.5,.5,.5>
//		lambda 2 //these you can tinker with
//		octaves 6 //for a variety of effects
//		omega .5 //though here they are at defaults.
//		}
	}
	finish {
//		specular .2 roughness 1
		phong 0.1 phong_size 90
		diffuse .55
		ambient 0.3
	}
}

#local Mortar = texture {
	pigment { Gray80 }
}

#local T_Wall = texture {
	brick
	texture { Mortar }
	texture { RoughStone }
	brick_size 1
	mortar 0.01
}

#local T_Roof = texture {
	pigment {
		bozo
		color_map {
			[ 0.00 color rgb <0.8, 0.1, 0.1> ]
			[ 0.80 color rgb <0.9, 0.3, 0.1> ]
			[ 1.00 color rgb <0.9, 0.2, 0.1> ]
		}
		turbulence 0.1
	}
	finish {
		specular 0.1
		roughness 0.2
		diffuse 0.7
	}
}

#local T_Door = texture {
	pigment { color DarkBrown }
	finish {
		metallic
		reflection 0.05
		phong 0.1
		phong_size 100
	}
}

#local Mud = texture {
	pigment {
		agate
		agate_turb 0.80
		lambda 7
		omega 0.6
		color_map {
			[0.10 rgb <0.780, 0.780, 0.780>]
			[0.60 rgb <0.890, 0.520, 0.270>]
			[0.60 rgb <0.600, 0.470, 0.320>]
			[0.68 rgb <0.270, 0.270, 0.300>]
			[0.72 rgb <0.560, 0.400, 0.440>]
			[1.00 rgb <0.520, 0.520, 0.560>]
		}
		scale 0.1
	}
	normal {bumps 0.3 turbulence 0.4 scale 0.02}
	finish {ambient 0.1 diffuse 0.5 crand 0.2}
}

#local Moss = texture {
  pigment {
    bozo
    color_map {
      [0.00 color rgb <0.200, 0.412, 0.247>]
      [0.12 color rgb <0.345, 0.600, 0.325>]
      [0.32 color rgb <0.020, 0.322, 0.067>]
      [0.49 color rgb <0.557, 0.761, 0.600>]
      [0.59 color rgb <0.192, 0.694, 0.298>]
      [0.80 color rgb <0.118, 0.412, 0.051>]
      [1.00 color rgb <0.420, 0.667, 0.455>]
    }
    scale 0.025
  }
  finish {ambient 0.1 diffuse 0.6}
}
texture {
  pigment {
    agate
    agate_turb 0.8
    color_map {
      [0.00 color rgbf <0.780, 0.941, 0.729, 0.761>]
      [0.22 color rgbf <0.561, 0.757, 0.580, 0.278>]
      [0.50 color rgbf <0.592, 0.737, 0.604, 0.098>]
      [0.64 color rgbf <0.098, 0.761, 0.329, 0.761>]
      [0.79 color rgbf <0.357, 0.675, 0.251, 0.506>]
      [0.87 color rgbf <0.102, 0.490, 0.204, 0.694>]
      [1.00 color rgbf <1.000, 1.000, 1.000, 0.365>]
    }
    scale 0.05
  }
  finish {ambient 0.1 diffuse 0.6 crand 0.1}
}

#local T_Ground = texture {
	bozo
	texture_map {
		[0.000 Mud]
		[0.400 Mud]
		[1.000 Moss scale 2/3]
	}
}  


// similar to T_Stone8, with a rocky normal
#declare T_Mountain =
texture{pigment{color White}
	finish{ambient 0.4 crand 0.06 diffuse 0.7}
}
texture{T_Grnt0a scale <.2, .3, .2> rotate <0, 0, -30>}
texture{T_Grnt9a scale <.5, .3, .4> rotate <0, 0, 40>
	finish{phong 1.0 ambient 0.2 diffuse 0.5 phong_size 90}
	normal {
		crackle 2.0
		turbulence .5
		lambda 2
		scale <2,1,2>
	}
}

#local T_HeightField = texture {
	gradient y
	texture_map {
		[ 0.00 RoughStone ]
		[ 0.399 RoughStone ]
		[ 0.402 T_Ground  ]
		[ 0.404 T_Mountain ]
		[ 1.00 T_Mountain ]
	}
}


// the keep
#declare Keep = merge {
	// the tower
	difference {
		merge {
			cylinder { <-40,  0, 5>, <-40, 28, 5> 10 }
			cylinder { <-40, 28, 5>, <-40, 31, 5> 11 }
		}

		cylinder { <-40, -1, 5>, <-40, 29, 5> 9 }
		box { <-2, -2, -2>, <2, 2, 2>
			rotate z*45
			scale <1, 1, 0.5>
			translate <-50, 28, 5>
		}

		// cut battlements
		box { <-20, 0, -0.75>, <20, 5, 0.75>
			rotate y*0
			translate <-40, 29, 5>
		}
		box { <-20, 0, -0.75>, <20, 5, 0.75>
			rotate y*45
			translate <-40, 29, 5>
		}
		box { <-20, 0, -0.75>, <20, 5, 0.75>
			rotate y*90
			translate <-40, 29, 5>
		}
		box { <-20, 0, -0.75>, <20, 5, 0.75>
			rotate y*135
			translate <-40, 29, 5>
		}

		texture { T_Wall }
	}

#local S = 10/sqrt(2);

	// the keep
	merge {
		box { <-40, 0, 0>, <20, 14, 20> }
		difference {
			box { <-39.99, -S, -S>, <19.99, S, S>
				rotate x*45
				scale <1, 0.6, 1>
				translate <0, 14, 10>
			}
			box { <-39, -1, -1>, <19, 30, 21> }
		}
		texture { T_Wall }
	}

	merge {
		box { <-30, 0, 20>, <-10, 14, 40> }
		difference {
			box { <-S, -S, 20.01>, <S, S, 39.99>
				rotate z*45
				scale <1, 0.6, 1>
				translate <-20, 14, 0>
			}
			box { <-31, -1, 0>, <-9, 30, 39> }
		}
		texture { T_Wall }
	}

	difference {
		merge {
			box { <-10, 0, 0>, <10, 12, 30> }
			difference {
				box { <-S, -S, 10>, <S, S, 29.99>
					rotate z*45
					scale <1, 0.8, 1>
					translate <0, 12, 0>
				}
				box { <-11, -1, 1>, <11, 30, 29> }
			}
		}
		box { <-4.5, -1, 29>, <4.5, 11.5, 31> }
		texture { T_Wall }
	}

	// front door
	box {
		<-4, 0, 28.9>, <4, 11, 29.1>
		texture { T_Door }
	}

	box { <-39.99, -S, -S>, <19.99, S, S>
		rotate x*45
		scale <1, 0.5, 1>
		translate <0, 14, 10>
		texture {T_Roof}
	}

	box { <-S, -S, 10>, <S, S, 39>
		rotate z*45
		scale <1, 0.5, 1>
		translate <-20, 14, 0>
		texture {T_Roof}
	}

	difference {
		box { <-S, -S, 10>, <S, S, 29>
			rotate z*45
			scale <1, 0.7, 1>
			translate <0, 12, 0>
		}
		box { <-20, 0, 9>, <20, 12, 30> }
		texture {T_Roof}
	}
}

object { Keep
	scale 0.56
	translate <10, -19, -110>
}

height_field {
	gif  "valley.gif"
	smooth
	rotate y*180
	texture { T_HeightField }

	scale <200, 400, 200>
	translate <100, -180, 50>
//	scale <500, 100, 600>
//	translate <155, -50, 555>
}

